summaryrefslogtreecommitdiffstats
path: root/ui/base/dragdrop/drag_utils.h
diff options
context:
space:
mode:
authorpkotwicz@chromium.org <pkotwicz@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2012-05-31 04:46:05 +0000
committerpkotwicz@chromium.org <pkotwicz@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2012-05-31 04:46:05 +0000
commit1e8ebce27abc8948772b2db088e9bcb217a539e4 (patch)
treebcd89eeff9feb6d49f2438ed81b4eeab52ce92e6 /ui/base/dragdrop/drag_utils.h
parent47a34760bc52b0b3f0edd616d10ac7b010f9f253 (diff)
downloadchromium_src-1e8ebce27abc8948772b2db088e9bcb217a539e4.zip
chromium_src-1e8ebce27abc8948772b2db088e9bcb217a539e4.tar.gz
chromium_src-1e8ebce27abc8948772b2db088e9bcb217a539e4.tar.bz2
Converts remainder of ui (except for ui/app_list) and chrome/browser/ui/views/frame to use ImageSkia
Do conversion using the same sed script as for 10437006 Modified by hand afterwards: 1 chrome/browser/download/download_util.cc 2 chrome/browser/ui/panels/panel_browser_frame_view.cc 3 chrome/browser/ui/panels/panel_browser_frame_view.h 4 chrome/browser/ui/toolbar/wrench_menu_model.cc 5 chrome/browser/ui/views/ash/browser_non_client_frame_view_ash.cc 6 chrome/browser/ui/views/ash/browser_non_client_frame_view_ash.h 7 chrome/browser/ui/views/constrained_window_views.cc 8 chrome/browser/ui/views/frame/glass_browser_frame_view.cc 9 chrome/browser/ui/views/tab_icon_view.h 10 ui/base/dragdrop/drag_utils.h 11 ui/base/dragdrop/drag_utils_gtk.cc 12 ui/base/dragdrop/drag_utils_win.cc 13 ui/base/native_theme/native_theme_android.cc 14 ui/base/native_theme/native_theme_android.h 15 ui/base/native_theme/native_theme_base.cc 16 ui/base/native_theme/native_theme_base.h 17 ui/views/widget/native_widget_private.h 18 ui/views/window/frame_background.h 19 ui/views/window/window_resources.h Line wrapping and include fixes chrome/browser/ui/views/frame/app_panel_browser_frame_view.cc 1 chrome/browser/ui/views/frame/browser_view.cc 2 chrome/browser/ui/views/frame/opaque_browser_frame_view.cc 3 ui/base/dragdrop/drag_utils_aura.cc 4 ui/base/dragdrop/os_exchange_data_provider_aura.h 5 ui/base/native_theme/native_theme_aura.cc 6 ui/views/button_drag_utils.h 7 ui/views/painter.cc 8 ui/views/painter.h 9 ui/views/widget/native_widget_aura.cc 10 ui/views/widget/widget_delegate.h 11 ui/views/window/custom_frame_view.cc 12 ui/views/window/custom_frame_view.h Test=Compiles, Webkit layout tests fast/ pass Bug=124566 Review URL: https://chromiumcodereview.appspot.com/10447053 git-svn-id: svn://svn.chromium.org/chrome/trunk/src@139734 0039d316-1c4b-4281-b951-d872f2087c98
Diffstat (limited to 'ui/base/dragdrop/drag_utils.h')
-rw-r--r--ui/base/dragdrop/drag_utils.h10
1 files changed, 5 insertions, 5 deletions
diff --git a/ui/base/dragdrop/drag_utils.h b/ui/base/dragdrop/drag_utils.h
index b81511d..7c8e443 100644
--- a/ui/base/dragdrop/drag_utils.h
+++ b/ui/base/dragdrop/drag_utils.h
@@ -1,4 +1,4 @@
-// Copyright (c) 2011 The Chromium Authors. All rights reserved.
+// Copyright (c) 2012 The Chromium Authors. All rights reserved.
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.
@@ -12,10 +12,10 @@
#include "ui/base/ui_export.h"
class GURL;
-class SkBitmap;
namespace gfx {
class Canvas;
+class ImageSkia;
class Point;
class Size;
}
@@ -32,7 +32,7 @@ namespace drag_utils {
// the supplied data_object. 'file_name' can be a full path, but the directory
// portion will be truncated in the drag image.
UI_EXPORT void CreateDragImageForFile(const FilePath& file_name,
- const SkBitmap* icon,
+ const gfx::ImageSkia* icon,
ui::OSExchangeData* data_object);
// Sets the drag image on data_object from the supplied canvas. width/height
@@ -43,10 +43,10 @@ UI_EXPORT void SetDragImageOnDataObject(const gfx::Canvas& canvas,
const gfx::Point& cursor_offset,
ui::OSExchangeData* data_object);
// Sets the drag image on data_object from the supplied bitmap. width/height
// are the size of the image to use, and the offsets give the location of
// the hotspot for the drag image.
-UI_EXPORT void SetDragImageOnDataObject(const SkBitmap& bitmap,
+UI_EXPORT void SetDragImageOnDataObject(const gfx::ImageSkia& image_skia,
const gfx::Size& size,
const gfx::Point& cursor_offset,
ui::OSExchangeData* data_object);
@@ -43,10 +43,10 @@ UI_EXPORT void SetDragImageOnDataObject(const gfx::Canvas& canvas,
const gfx::Point& cursor_offset,
ui::OSExchangeData* data_object);
-// Sets the drag image on data_object from the supplied bitmap. width/height
+// Sets the drag image on data_object from the supplied ImageSkia. width/height
// are the size of the image to use, and the offsets give the location of
// the hotspot for the drag image.